@@ -7,17 +7,17 @@ use crossterm::event::{KeyEvent, KeyModifiers};
 use crossterm::{
     event::{Event, KeyCode},
     execute,
-    terminal::{disable_raw_mode, enable_raw_mode, EnterAlternateScreen, LeaveAlternateScreen},
+    terminal::{EnterAlternateScreen, LeaveAlternateScreen, disable_raw_mode, enable_raw_mode},
 };
 use forensic_adb::{AndroidStorageInput, DeviceInfo, Host};
 use indexmap::IndexMap;
 use ratatui::{
+    Frame, Terminal,
     backend::{Backend, CrosstermBackend},
     layout::{Alignment, Constraint, Direction, Layout},
     style::{Color, Modifier, Style},
     text::{Line, Span, Text},
     widgets::{Block, Borders, List, ListItem, Paragraph},
-    Frame, Terminal,
 };
 use std::cmp::Ordering;
 use std::collections::BTreeSet;
